/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2012 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp12nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp12nid ;

DATA library.&dataset ;
INFILE datafile LRECL=5148;
INPUT
   DISGORGE  1-7            NEWCNVTN  8              ACCEPT  9-10          
   BOOKER2  11              BOOKER3  12              BOOKERCD  13-14       
   BUSCLAS  15-18           CANTPAY  19              CCULPSCO  20          
   CH2APP  21               CH8FINGD  22             CMSRVORD  23          
   COFI  24                 COMPLY  25               COMPLYPR  26          
   CRIMPURP  27             DETBFINE  28             DISPOSIT  29          
   EMPLOYNM  30             FCULPSCO  31             FRAUDTYP  32-33       
   FINSTDS  34              HISTORY  35              HSMISCND  36          
   INCORLOC  37             INCORPYR  38-41          INDICT  42            
   INPLEA1  43              INPLEA2  44              INPLEA3  45           
   INPLEA4  46              INPLEA5  47              INPLEA6  48           
   INPLEA7  49              INPLEA8  50              INPLEA9  51           
   INPLEA10  52             INPLEA11  53             INPLEA12  54          
   INNOPL1  55              INNOPL2  56              INNOPL3  57           
   INNOPL4  58              INNOPL5  59              INNOPL6  60           
   INNOPL7  61              INNOPL8  62              INNOPL9  63           
   INNOPL10  64             INNOPL11  65             INNOPL12  66          
   JANDC  67                NOCOMP  68               NOCOUNTS  69-71       
   NOUSTAT  72              OBSTRUCT  73             OFFLVL  74-75         
   ORDERCE  76              ORGTYPE  77              OWNSTRCT  78-79       
   PLEA  80                 PRIMOFF  81-82           PRCIVIL  83           
   PRCRIME  84              PROBATN  85-86           PROBMON  87           
   PSR  88                  QUARTER  89              REAS1  90-93          
   REAS2  94-96             REAS3  97                REAS4  98             
   REAS5  99                REAS6  100               REAS7  101            
   REAS8  102               REAS9  103               REAS10  104           
   REASONS  105             REMEDORD  106            SELFREP  107          
   SOURCES  108             TOLERNCE  109            TYPEOTHS  110-111     
   VICTNOTE  112            VIOLATE  113             AMENDYR  114-117      
   SENTYR  118-121          BASEFINE  122-130        COSTASSM  131-136     
   FINOFFST  137-142        FORFEITR  143-150        GLFINMAX  151-160     
   GLFINMIN  161-169        STATMIN  170-175         STATMAX  176-185      
   CPIDN  186-192           BUSTEXT $ 193-243        OWNSTEXT $ 244-254    
   FINSTXT $ 255-286        PRMONTXT $ 287-383       TYPEOTTX $ 384-583    
   ORDERTXT $ 584-683       MINFINML  684-687        MAXFINML  688-690     
   ADJOFL1  691-692         ADJOFL2  693-694         ADJOFLHI  695-696     
   ADJ_B1  697-698          ADJ_B2  699              ADJ_BHI  700-701      
   ADJ_C1  702-703          ADJ_C2  704-705          ADJ_CHI  706-707      
   ADJ_D1  708-710          ADJ_D2  711              ADJ_DHI  712-714      
   ADJ_E1  715              ADJ_E2  716              ADJ_EHI  717          
   ADJ_F1  718              ADJ_F2  719              ADJ_FHI  720          
   ADJ_G1  721              ADJ_G2  722              ADJ_GHI  723          
   ADJ_H1  724              ADJ_H2  725              ADJ_HHI  726          
   ADJ_I1  727              ADJ_I2  728              ADJ_IHI  729          
   ADJ_J1  730              ADJ_J2  731              ADJ_JHI  732          
   ADJ_K1  733              ADJ_K2  734              ADJ_KHI  735          
   ADJ_L1  736              ADJ_L2  737              ADJ_LHI  738          
   ADJ_M1  739              ADJ_M2  740              ADJ_MHI  741          
   ADJ_N1  742              ADJ_N2  743              ADJ_NHI  744          
   ADJ_O1  745              ADJ_O2  746              ADJ_OHI  747          
   ADJ_P1  748              ADJ_P2  749              ADJ_PHI  750          
   ADJ_Q1  751              ADJ_Q2  752              ADJ_QHI  753          
   ADJ_R1  754              ADJ_R2  755              ADJ_RHI  756          
   ADJ_S1  757              ADJ_S2  758              ADJ_SHI  759          
   BASADJ1  760-761         BASADJ2  762             BASADJHI  763-764     
   BASE1  765-766           BASE2  767-768           BASEHI  769-770       
   BASLN1  771              BASLN2  772              BASLNHI  773          
   ADJOFR1  774-775         ADJOFR2  776             ADJOFRHI  777-778     
   ADJR_B1  779-780         ADJR_B2  781             ADJR_BHI  782-783     
   ADJR_C1  784-785         ADJR_C2  786             ADJR_CHI  787-788     
   ADJR_D1  789             ADJR_D2  790             ADJR_DHI  791         
   ADJR_E1  792             ADJR_E2  793             ADJR_EHI  794         
   ADJR_F1  795             ADJR_F2  796             ADJR_FHI  797         
   ADJR_G1  798             ADJR_G2  799             ADJR_GHI  800         
   ADJR_H1  801             ADJR_H2  802             ADJR_HHI  803         
   ADJR_I1  804             ADJR_I2  805             ADJR_IHI  806         
   ADJR_J1  807             ADJR_J2  808             ADJR_JHI  809         
   ADJR_K1  810             ADJR_K2  811             ADJR_KHI  812         
   ADJR_L1  813             ADJR_L2  814             ADJR_LHI  815         
   ADJR_M1  816             ADJR_M2  817             ADJR_MHI  818         
   ADJR_N1  819             ADJR_N2  820             ADJR_NHI  821         
   ADJR_O1  822             ADJR_O2  823             ADJR_OHI  824         
   ADJR_P1  825             ADJR_P2  826             ADJR_PHI  827         
   ADJR_Q1  828             ADJR_Q2  829             ADJR_QHI  830         
   ADJR_R1  831             ADJR_R2  832             ADJR_RHI  833         
   ADJR_S1  834             ADJR_S2  835             ADJR_SHI  836         
   BASADR1  837             BASADR2  838             BASADRHI  839         
   BASER1  840-841          BASER2  842              BASERHI  843-844      
   BASLNR1  845             BASLNR2  846             BASLNRHI  847         
   ADJOFS1  848-849         ADJOFS2  850-851         ADJOFSHI  852-853     
   ADJS_B1  854-855         ADJS_B2  856             ADJS_BHI  857-858     
   ADJS_C1  859-860         ADJS_C2  861-862         ADJS_CHI  863-864     
   ADJS_D1  865-867         ADJS_D2  868             ADJS_DHI  869-871     
   ADJS_E1  872             ADJS_E2  873             ADJS_EHI  874         
   ADJS_F1  875             ADJS_F2  876             ADJS_FHI  877         
   ADJS_G1  878             ADJS_G2  879             ADJS_GHI  880         
   ADJS_H1  881             ADJS_H2  882             ADJS_HHI  883         
   ADJS_I1  884             ADJS_I2  885             ADJS_IHI  886         
   ADJS_J1  887             ADJS_J2  888             ADJS_JHI  889         
   ADJS_K1  890             ADJS_K2  891             ADJS_KHI  892         
   ADJS_L1  893             ADJS_L2  894             ADJS_LHI  895         
   ADJS_M1  896             ADJS_M2  897             ADJS_MHI  898         
   ADJS_N1  899             ADJS_N2  900             ADJS_NHI  901         
   ADJS_O1  902             ADJS_O2  903             ADJS_OHI  904         
   ADJS_P1  905             ADJS_P2  906             ADJS_PHI  907         
   ADJS_Q1  908             ADJS_Q2  909             ADJS_QHI  910         
   ADJS_R1  911             ADJS_R2  912             ADJS_RHI  913         
   ADJS_S1  914             ADJS_S2  915             ADJS_SHI  916         
   BASADS1  917-918         BASADS2  919             BASADSHI  920-921     
   BASES1  922-923          BASES2  924-925          BASESHI  926-927      
   BASLNS1  928             BASLNS2  929             BASLNSHI  930         
   ADJOFC1  931             ADJOFC2  932-933         ADJOFCHI  934         
   ADJC_B1  935             ADJC_B2  936             ADJC_BHI  937         
   ADJC_C1  938             ADJC_C2  939             ADJC_CHI  940         
   ADJC_D1  941             ADJC_D2  942             ADJC_DHI  943         
   ADJC_E1  944             ADJC_E2  945             ADJC_EHI  946         
   ADJC_F1  947             ADJC_F2  948             ADJC_FHI  949         
   ADJC_G1  950             ADJC_G2  951             ADJC_GHI  952         
   ADJC_H1  953             ADJC_H2  954             ADJC_HHI  955         
   ADJC_I1  956             ADJC_I2  957             ADJC_IHI  958         
   ADJC_J1  959             ADJC_J2  960             ADJC_JHI  961         
   ADJC_K1  962             ADJC_K2  963             ADJC_KHI  964         
   ADJC_L1  965             ADJC_L2  966             ADJC_LHI  967         
   ADJC_M1  968             ADJC_M2  969             ADJC_MHI  970         
   ADJC_N1  971             ADJC_N2  972             ADJC_NHI  973         
   ADJC_O1  974             ADJC_O2  975             ADJC_OHI  976         
   ADJC_P1  977             ADJC_P2  978             ADJC_PHI  979         
   ADJC_Q1  980             ADJC_Q2  981             ADJC_QHI  982         
   ADJC_R1  983             ADJC_R2  984             ADJC_RHI  985         
   ADJC_S1  986             ADJC_S2  987             ADJC_SHI  988         
   BASADC1  989             BASADC2  990             BASADCHI  991         
   BASEC1  992              BASEC2  993              BASECHI  994          
   BASLNC1  995             BASLNC2  996             BASLNCHI  997         
   ADJOFU1  998             ADJOFU2  999             ADJOFUHI  1000        
   ADJU_B1  1001            ADJU_B2  1002            ADJU_BHI  1003        
   ADJU_C1  1004            ADJU_C2  1005            ADJU_CHI  1006        
   ADJU_D1  1007            ADJU_D2  1008            ADJU_DHI  1009        
   ADJU_E1  1010            ADJU_E2  1011            ADJU_EHI  1012        
   ADJU_F1  1013            ADJU_F2  1014            ADJU_FHI  1015        
   ADJU_G1  1016            ADJU_G2  1017            ADJU_GHI  1018        
   ADJU_H1  1019            ADJU_H2  1020            ADJU_HHI  1021        
   ADJU_I1  1022            ADJU_I2  1023            ADJU_IHI  1024        
   ADJU_J1  1025            ADJU_J2  1026            ADJU_JHI  1027        
   ADJU_K1  1028            ADJU_K2  1029            ADJU_KHI  1030        
   ADJU_L1  1031            ADJU_L2  1032            ADJU_LHI  1033        
   ADJU_M1  1034            ADJU_M2  1035            ADJU_MHI  1036        
   ADJU_N1  1037            ADJU_N2  1038            ADJU_NHI  1039        
   ADJU_O1  1040            ADJU_O2  1041            ADJU_OHI  1042        
   ADJU_P1  1043            ADJU_P2  1044            ADJU_PHI  1045        
   ADJU_Q1  1046            ADJU_Q2  1047            ADJU_QHI  1048        
   ADJU_R1  1049            ADJU_R2  1050            ADJU_RHI  1051        
   ADJU_S1  1052            ADJU_S2  1053            ADJU_SHI  1054        
   BASADU1  1055            BASADU2  1056            BASADUHI  1057        
   BASEU1  1058             BASEU2  1059             BASEUHI  1060         
   BASLNU1  1061            BASLNU2  1062            BASLNUHI  1063        
   ADJL_B1 $ 1064           ADJL_B2 $ 1065           ADJL_BHI $ 1066       
   ADJL_C1 $ 1067-1068      ADJL_C2 $ 1069           ADJL_CHI $ 1070-1071  
   ADJL_D1 $ 1072           ADJL_D2 $ 1073           ADJL_DHI $ 1074       
   ADJL_E1 $ 1075           ADJL_E2 $ 1076           ADJL_EHI $ 1077       
   ADJL_F1 $ 1078           ADJL_F2 $ 1079           ADJL_FHI $ 1080       
   ADJL_G1 $ 1081           ADJL_G2 $ 1082           ADJL_GHI $ 1083       
   ADJL_H1 $ 1084           ADJL_H2 $ 1085           ADJL_HHI $ 1086       
   ADJL_I1 $ 1087           ADJL_I2 $ 1088           ADJL_IHI $ 1089       
   ADJL_J1 $ 1090           ADJL_J2 $ 1091           ADJL_JHI $ 1092       
   ADJL_K1 $ 1093           ADJL_K2 $ 1094           ADJL_KHI $ 1095       
   ADJL_L1 $ 1096           ADJL_L2 $ 1097           ADJL_LHI $ 1098       
   ADJL_M1 $ 1099           ADJL_M2 $ 1100           ADJL_MHI $ 1101       
   ADJL_N1 $ 1102           ADJL_N2 $ 1103           ADJL_NHI $ 1104       
   ADJL_O1 $ 1105           ADJL_O2 $ 1106           ADJL_OHI $ 1107       
   ADJL_P1 $ 1108           ADJL_P2 $ 1109           ADJL_PHI $ 1110       
   ADJL_Q1 $ 1111           ADJL_Q2 $ 1112           ADJL_QHI $ 1113       
   ADJL_R1 $ 1114           ADJL_R2 $ 1115           ADJL_RHI $ 1116       
   ADJL_S1 $ 1117           ADJL_S2 $ 1118           ADJL_SHI $ 1119       
   BASEL1 $ 1120            BASEL2 $ 1121            BASELHI $ 1122        
   ADRL_B1 $ 1123           ADRL_B2 $ 1124           ADRL_BHI $ 1125       
   ADRL_C1 $ 1126-1127      ADRL_C2 $ 1128           ADRL_CHI $ 1129-1130  
   ADRL_D1 $ 1131           ADRL_D2 $ 1132           ADRL_DHI $ 1133       
   ADRL_E1 $ 1134           ADRL_E2 $ 1135           ADRL_EHI $ 1136       
   ADRL_F1 $ 1137           ADRL_F2 $ 1138           ADRL_FHI $ 1139       
   ADRL_G1 $ 1140           ADRL_G2 $ 1141           ADRL_GHI $ 1142       
   ADRL_H1 $ 1143           ADRL_H2 $ 1144           ADRL_HHI $ 1145       
   ADRL_I1 $ 1146           ADRL_I2 $ 1147           ADRL_IHI $ 1148       
   ADRL_J1 $ 1149           ADRL_J2 $ 1150           ADRL_JHI $ 1151       
   ADRL_K1 $ 1152           ADRL_K2 $ 1153           ADRL_KHI $ 1154       
   ADRL_L1 $ 1155           ADRL_L2 $ 1156           ADRL_LHI $ 1157       
   ADRL_M1 $ 1158           ADRL_M2 $ 1159           ADRL_MHI $ 1160       
   ADRL_N1 $ 1161           ADRL_N2 $ 1162           ADRL_NHI $ 1163       
   ADRL_O1 $ 1164           ADRL_O2 $ 1165           ADRL_OHI $ 1166       
   ADRL_P1 $ 1167           ADRL_P2 $ 1168           ADRL_PHI $ 1169       
   ADRL_Q1 $ 1170           ADRL_Q2 $ 1171           ADRL_QHI $ 1172       
   ADRL_R1 $ 1173           ADRL_R2 $ 1174           ADRL_RHI $ 1175       
   ADRL_S1 $ 1176           ADRL_S2 $ 1177           ADRL_SHI $ 1178       
   BASERL1 $ 1179           BASERL2 $ 1180           BASERLHI $ 1181       
   ADSL_B1 $ 1182           ADSL_B2 $ 1183           ADSL_BHI $ 1184       
   ADSL_C1 $ 1185           ADSL_C2 $ 1186           ADSL_CHI $ 1187       
   ADSL_D1 $ 1188           ADSL_D2 $ 1189           ADSL_DHI $ 1190       
   ADSL_E1 $ 1191           ADSL_E2 $ 1192           ADSL_EHI $ 1193       
   ADSL_F1 $ 1194           ADSL_F2 $ 1195           ADSL_FHI $ 1196       
   ADSL_G1 $ 1197           ADSL_G2 $ 1198           ADSL_GHI $ 1199       
   ADSL_H1 $ 1200           ADSL_H2 $ 1201           ADSL_HHI $ 1202       
   ADSL_I1 $ 1203           ADSL_I2 $ 1204           ADSL_IHI $ 1205       
   ADSL_J1 $ 1206           ADSL_J2 $ 1207           ADSL_JHI $ 1208       
   ADSL_K1 $ 1209           ADSL_K2 $ 1210           ADSL_KHI $ 1211       
   ADSL_L1 $ 1212           ADSL_L2 $ 1213           ADSL_LHI $ 1214       
   ADSL_M1 $ 1215           ADSL_M2 $ 1216           ADSL_MHI $ 1217       
   ADSL_N1 $ 1218           ADSL_N2 $ 1219           ADSL_NHI $ 1220       
   ADSL_O1 $ 1221           ADSL_O2 $ 1222           ADSL_OHI $ 1223       
   ADSL_P1 $ 1224           ADSL_P2 $ 1225           ADSL_PHI $ 1226       
   ADSL_Q1 $ 1227           ADSL_Q2 $ 1228           ADSL_QHI $ 1229       
   ADSL_R1 $ 1230           ADSL_R2 $ 1231           ADSL_RHI $ 1232       
   ADSL_S1 $ 1233           ADSL_S2 $ 1234           ADSL_SHI $ 1235       
   BASESL1 $ 1236           BASESL2 $ 1237           BASESLHI $ 1238       
   ADCL_B1 $ 1239           ADCL_B2 $ 1240           ADCL_BHI $ 1241       
   ADCL_C1 $ 1242           ADCL_C2 $ 1243           ADCL_CHI $ 1244       
   ADCL_D1 $ 1245           ADCL_D2 $ 1246           ADCL_DHI $ 1247       
   ADCL_E1 $ 1248           ADCL_E2 $ 1249           ADCL_EHI $ 1250       
   ADCL_F1 $ 1251           ADCL_F2 $ 1252           ADCL_FHI $ 1253       
   ADCL_G1 $ 1254           ADCL_G2 $ 1255           ADCL_GHI $ 1256       
   ADCL_H1 $ 1257           ADCL_H2 $ 1258           ADCL_HHI $ 1259       
   ADCL_I1 $ 1260           ADCL_I2 $ 1261           ADCL_IHI $ 1262       
   ADCL_J1 $ 1263           ADCL_J2 $ 1264           ADCL_JHI $ 1265       
   ADCL_K1 $ 1266           ADCL_K2 $ 1267           ADCL_KHI $ 1268       
   ADCL_L1 $ 1269           ADCL_L2 $ 1270           ADCL_LHI $ 1271       
   ADCL_M1 $ 1272           ADCL_M2 $ 1273           ADCL_MHI $ 1274       
   ADCL_N1 $ 1275           ADCL_N2 $ 1276           ADCL_NHI $ 1277       
   ADCL_O1 $ 1278           ADCL_O2 $ 1279           ADCL_OHI $ 1280       
   ADCL_P1 $ 1281           ADCL_P2 $ 1282           ADCL_PHI $ 1283       
   ADCL_Q1 $ 1284           ADCL_Q2 $ 1285           ADCL_QHI $ 1286       
   ADCL_R1 $ 1287           ADCL_R2 $ 1288           ADCL_RHI $ 1289       
   ADCL_S1 $ 1290           ADCL_S2 $ 1291           ADCL_SHI $ 1292       
   BASECL1 $ 1293           BASECL2 $ 1294           BASECLHI $ 1295       
   ADUL_B1 $ 1296           ADUL_B2 $ 1297           ADUL_BHI $ 1298       
   ADUL_C1 $ 1299           ADUL_C2 $ 1300           ADUL_CHI $ 1301       
   ADUL_D1 $ 1302           ADUL_D2 $ 1303           ADUL_DHI $ 1304       
   ADUL_E1 $ 1305           ADUL_E2 $ 1306           ADUL_EHI $ 1307       
   ADUL_F1 $ 1308           ADUL_F2 $ 1309           ADUL_FHI $ 1310       
   ADUL_G1 $ 1311           ADUL_G2 $ 1312           ADUL_GHI $ 1313       
   ADUL_H1 $ 1314           ADUL_H2 $ 1315           ADUL_HHI $ 1316       
   ADUL_I1 $ 1317           ADUL_I2 $ 1318           ADUL_IHI $ 1319       
   ADUL_J1 $ 1320           ADUL_J2 $ 1321           ADUL_JHI $ 1322       
   ADUL_K1 $ 1323           ADUL_K2 $ 1324           ADUL_KHI $ 1325       
   ADUL_L1 $ 1326           ADUL_L2 $ 1327           ADUL_LHI $ 1328       
   ADUL_M1 $ 1329           ADUL_M2 $ 1330           ADUL_MHI $ 1331       
   ADUL_N1 $ 1332           ADUL_N2 $ 1333           ADUL_NHI $ 1334       
   ADUL_O1 $ 1335           ADUL_O2 $ 1336           ADUL_OHI $ 1337       
   ADUL_P1 $ 1338           ADUL_P2 $ 1339           ADUL_PHI $ 1340       
   ADUL_Q1 $ 1341           ADUL_Q2 $ 1342           ADUL_QHI $ 1343       
   ADUL_R1 $ 1344           ADUL_R2 $ 1345           ADUL_RHI $ 1346       
   ADUL_S1 $ 1347           ADUL_S2 $ 1348           ADUL_SHI $ 1349       
   BASEUL1 $ 1350           BASEUL2 $ 1351           BASEULHI $ 1352       
   GDLINE1 $ 1353-1357      GDLINE2 $ 1358-1362      GDSTAT1 $ 1363-1367   
   GDSTAT2 $ 1368-1372      GDREF1 $ 1373-1377       GDREF2 $ 1378-1382    
   GDCROS1 $ 1383           GDCROS2 $ 1384-1388      GDUNDR1 $ 1389        
   GDUNDR2 $ 1390           GDLINEHI $ 1391-1395     GDSTATHI $ 1396-1400  
   GDREFHI $ 1401-1405      GDCROSHI $ 1406          GDUNDRHI $ 1407       
   STA1_1 $ 1408-1418       STA1_2 $ 1419-1428       STA1_3 $ 1429-1437    
   STA1_4 $ 1438-1445       STA1_5 $ 1446-1453       STA1_6 $ 1454-1461    
   STA1_7 $ 1462-1469       STA1_8 $ 1470-1477       STA1_9 $ 1478-1485    
   STA1_10 $ 1486-1493      STA1_11 $ 1494-1501      STA1_12 $ 1502-1509   
   STA1_13 $ 1510-1517      STA1_14 $ 1518-1525      STA1_15 $ 1526-1533   
   STA1_16 $ 1534-1541      STA1_17 $ 1542-1549      STA1_18 $ 1550-1557   
   STA1_19 $ 1558-1565      STA1_20 $ 1566-1573      STA1_21 $ 1574-1581   
   STA1_22 $ 1582-1589      STA1_23 $ 1590-1597      STA1_24 $ 1598-1605   
   STA1_25 $ 1606-1613      STA1_26 $ 1614-1621      STA1_27 $ 1622-1629   
   STA1_28 $ 1630-1637      STA1_29 $ 1638-1645      STA1_30 $ 1646-1653   
   STA1_31 $ 1654-1661      STA1_32 $ 1662-1669      STA1_33 $ 1670-1677   
   STA1_34 $ 1678-1685      STA1_35 $ 1686-1693      STA1_36 $ 1694-1701   
   STA1_37 $ 1702-1709      STA1_38 $ 1710-1717      STA1_39 $ 1718-1725   
   STA1_40 $ 1726-1733      STA1_41 $ 1734-1741      STA1_42 $ 1742-1749   
   STA1_43 $ 1750-1757      STA1_44 $ 1758-1765      STA1_45 $ 1766-1773   
   STA1_46 $ 1774-1781      STA1_47 $ 1782-1789      STA1_48 $ 1790-1797   
   STA1_49 $ 1798-1805      STA1_50 $ 1806-1813      STA1_51 $ 1814-1821   
   STA1_52 $ 1822-1829      STA1_53 $ 1830-1837      STA1_54 $ 1838-1845   
   STA1_55 $ 1846-1853      STA1_56 $ 1854-1861      STA1_57 $ 1862-1869   
   STA1_58 $ 1870-1877      STA1_59 $ 1878-1885      STA1_60 $ 1886-1893   
   STA1_61 $ 1894-1901      STA1_62 $ 1902-1909      STA1_63 $ 1910-1917   
   STA1_64 $ 1918-1925      STA1_65 $ 1926-1933      STA1_66 $ 1934-1941   
   STA1_67 $ 1942-1949      STA1_68 $ 1950-1957      STA1_69 $ 1958-1965   
   STA1_70 $ 1966-1973      STA1_71 $ 1974-1981      STA1_72 $ 1982-1989   
   STA1_73 $ 1990-1997      STA1_74 $ 1998-2005      STA1_75 $ 2006-2013   
   STA1_76 $ 2014-2021      STA1_77 $ 2022-2029      STA1_78 $ 2030-2037   
   STA1_79 $ 2038-2045      STA1_80 $ 2046-2053      STA1_81 $ 2054-2061   
   STA1_82 $ 2062-2069      STA1_83 $ 2070-2077      STA1_84 $ 2078-2085   
   STA1_85 $ 2086-2093      STA1_86 $ 2094-2101      STA1_87 $ 2102-2109   
   STA1_88 $ 2110-2117      STA1_89 $ 2118-2125      STA1_90 $ 2126-2133   
   STA1_91 $ 2134-2141      STA1_92 $ 2142-2149      STA1_93 $ 2150-2157   
   STA1_94 $ 2158-2165      STA1_95 $ 2166-2173      STA1_96 $ 2174-2181   
   STA1_97 $ 2182-2189      STA1_98 $ 2190-2197      STA1_99 $ 2198-2205   
   STA1_100 $ 2206-2213     STA1_101 $ 2214-2221     STA1_102 $ 2222-2229  
   STA1_103 $ 2230-2237     STA1_104 $ 2238-2245     STA1_105 $ 2246-2253  
   STA1_106 $ 2254-2261     STA1_107 $ 2262-2269     STA1_108 $ 2270-2277  
   STA1_109 $ 2278-2285     STA1_110 $ 2286-2293     STA1_111 $ 2294-2301  
   STA1_112 $ 2302-2309     STA1_113 $ 2310-2317     STA1_114 $ 2318-2325  
   STA1_115 $ 2326-2333     STA1_116 $ 2334-2341     STA1_117 $ 2342-2349  
   STA1_118 $ 2350-2357     STA1_119 $ 2358-2365     STA1_120 $ 2366-2373  
   STA1_121 $ 2374-2381     STA1_122 $ 2382-2389     STA1_123 $ 2390-2397  
   STA1_124 $ 2398-2405     STA1_125 $ 2406-2413     STA1_126 $ 2414-2421  
   STA1_127 $ 2422-2429     STA1_128 $ 2430-2437     STA1_129 $ 2438-2445  
   STA1_130 $ 2446-2453     STA1_131 $ 2454-2461     STA1_132 $ 2462-2469  
   STA1_133 $ 2470-2477     STA1_134 $ 2478-2485     STA1_135 $ 2486-2493  
   STA1_136 $ 2494-2501     STA1_137 $ 2502-2509     STA1_138 $ 2510-2517  
   STA1_139 $ 2518-2525     STA1_140 $ 2526-2533     STA1_141 $ 2534-2541  
   STA1_142 $ 2542-2549     STA1_143 $ 2550-2557     STA1_144 $ 2558-2565  
   STA1_145 $ 2566-2573     STA1_146 $ 2574-2581     STA1_147 $ 2582-2589  
   STA1_148 $ 2590-2597     STA1_149 $ 2598-2605     STA1_150 $ 2606-2613  
   STA2_1 $ 2614-2623       STA2_2 $ 2624-2634       STA2_3 $ 2635-2643    
   STA2_4 $ 2644-2651       STA2_5 $ 2652-2659       STA2_6 $ 2660-2667    
   STA2_7 $ 2668-2675       STA2_8 $ 2676-2683       STA2_9 $ 2684-2691    
   STA2_10 $ 2692-2699      STA2_11 $ 2700-2707      STA2_12 $ 2708-2715   
   STA2_13 $ 2716-2723      STA2_14 $ 2724-2731      STA2_15 $ 2732-2739   
   STA2_16 $ 2740-2747      STA2_17 $ 2748-2755      STA2_18 $ 2756-2763   
   STA2_19 $ 2764-2771      STA2_20 $ 2772-2779      STA2_21 $ 2780-2787   
   STA2_22 $ 2788-2795      STA2_23 $ 2796-2803      STA2_24 $ 2804-2811   
   STA2_25 $ 2812-2819      STA2_26 $ 2820-2827      STA2_27 $ 2828-2835   
   STA2_28 $ 2836-2843      STA2_29 $ 2844-2851      STA2_30 $ 2852-2859   
   STA2_31 $ 2860-2867      STA2_32 $ 2868-2875      STA2_33 $ 2876-2883   
   STA2_34 $ 2884-2891      STA2_35 $ 2892-2899      STA2_36 $ 2900-2907   
   STA2_37 $ 2908-2915      STA2_38 $ 2916-2923      STA2_39 $ 2924-2931   
   STA2_40 $ 2932-2939      STA2_41 $ 2940-2947      STA2_42 $ 2948-2955   
   STA2_43 $ 2956-2963      STA2_44 $ 2964-2971      STA2_45 $ 2972-2979   
   STA2_46 $ 2980-2987      STA2_47 $ 2988-2995      STA2_48 $ 2996-3003   
   STA2_49 $ 3004-3011      STA2_50 $ 3012-3019      STA2_51 $ 3020-3027   
   STA2_52 $ 3028-3035      STA2_53 $ 3036-3043      STA2_54 $ 3044-3051   
   STA2_55 $ 3052-3059      STA2_56 $ 3060-3067      STA2_57 $ 3068-3075   
   STA2_58 $ 3076-3083      STA2_59 $ 3084-3091      STA2_60 $ 3092-3099   
   STA2_61 $ 3100-3107      STA2_62 $ 3108-3115      STA2_63 $ 3116-3123   
   STA2_64 $ 3124-3131      STA2_65 $ 3132-3139      STA2_66 $ 3140-3147   
   STA2_67 $ 3148-3155      STA2_68 $ 3156-3163      STA2_69 $ 3164-3171   
   STA2_70 $ 3172-3179      STA2_71 $ 3180-3187      STA2_72 $ 3188-3195   
   STA2_73 $ 3196-3203      STA2_74 $ 3204-3211      STA2_75 $ 3212-3219   
   STA2_76 $ 3220-3227      STA2_77 $ 3228-3235      STA2_78 $ 3236-3243   
   STA2_79 $ 3244-3251      STA2_80 $ 3252-3259      STA2_81 $ 3260-3267   
   STA2_82 $ 3268-3275      STA2_83 $ 3276-3283      STA2_84 $ 3284-3291   
   STA2_85 $ 3292-3299      STA2_86 $ 3300-3307      STA2_87 $ 3308-3315   
   STA2_88 $ 3316-3323      STA2_89 $ 3324-3331      STA2_90 $ 3332-3339   
   STA2_91 $ 3340-3347      STA2_92 $ 3348-3355      STA2_93 $ 3356-3363   
   STA2_94 $ 3364-3371      STA2_95 $ 3372-3379      STA2_96 $ 3380-3387   
   STA2_97 $ 3388-3395      STA2_98 $ 3396-3403      STA2_99 $ 3404-3411   
   STA2_100 $ 3412-3419     STA2_101 $ 3420-3427     STA2_102 $ 3428-3435  
   STA2_103 $ 3436-3443     STA2_104 $ 3444-3451     STA2_105 $ 3452-3459  
   STA2_106 $ 3460-3467     STA2_107 $ 3468-3475     STA2_108 $ 3476-3483  
   STA2_109 $ 3484-3491     STA2_110 $ 3492-3499     STA2_111 $ 3500-3507  
   STA2_112 $ 3508-3515     STA2_113 $ 3516-3523     STA2_114 $ 3524-3531  
   STA2_115 $ 3532-3539     STA2_116 $ 3540-3547     STA2_117 $ 3548-3555  
   STA2_118 $ 3556-3563     STA2_119 $ 3564-3571     STA2_120 $ 3572-3579  
   STA2_121 $ 3580-3587     STA2_122 $ 3588-3595     STA2_123 $ 3596-3603  
   STA2_124 $ 3604-3611     STA2_125 $ 3612-3619     STA2_126 $ 3620-3627  
   STA2_127 $ 3628-3635     STA2_128 $ 3636-3643     STA2_129 $ 3644-3651  
   STA2_130 $ 3652-3659     STA2_131 $ 3660-3667     STA2_132 $ 3668-3675  
   STA2_133 $ 3676-3683     STA2_134 $ 3684-3691     STA2_135 $ 3692-3699  
   STA2_136 $ 3700-3707     STA2_137 $ 3708-3715     STA2_138 $ 3716-3723  
   STA2_139 $ 3724-3731     STA2_140 $ 3732-3739     STA2_141 $ 3740-3747  
   STA2_142 $ 3748-3755     STA2_143 $ 3756-3763     STA2_144 $ 3764-3771  
   STA2_145 $ 3772-3779     STA2_146 $ 3780-3787     STA2_147 $ 3788-3795  
   STA2_148 $ 3796-3803     STA2_149 $ 3804-3811     STA2_150 $ 3812-3819  
   STA3_1 $ 3820-3829       STA3_2 $ 3830-3837       STA3_3 $ 3838-3844    
   STA3_4 $ 3845-3851       STA3_5 $ 3852-3858       STA3_6 $ 3859-3865    
   STA3_7 $ 3866-3872       STA3_8 $ 3873            STA3_9 $ 3874         
   STA3_10 $ 3875           STA3_11 $ 3876           STA3_12 $ 3877        
   STA3_13 $ 3878           STA3_14 $ 3879           STA3_15 $ 3880        
   STA3_16 $ 3881           STA3_17 $ 3882           STA3_18 $ 3883        
   STA3_19 $ 3884           STA3_20 $ 3885           STA3_21 $ 3886        
   STA3_22 $ 3887           STA3_23 $ 3888           STA3_24 $ 3889        
   STA3_25 $ 3890           STA3_26 $ 3891           STA3_27 $ 3892        
   STA3_28 $ 3893           STA3_29 $ 3894           STA3_30 $ 3895        
   STA3_31 $ 3896           STA3_32 $ 3897           STA3_33 $ 3898        
   STA3_34 $ 3899           STA3_35 $ 3900           STA3_36 $ 3901        
   STA3_37 $ 3902           STA3_38 $ 3903           STA3_39 $ 3904        
   STA3_40 $ 3905           STA3_41 $ 3906           STA3_42 $ 3907        
   STA3_43 $ 3908           STA3_44 $ 3909           STA3_45 $ 3910        
   STA3_46 $ 3911           STA3_47 $ 3912           STA3_48 $ 3913        
   STA3_49 $ 3914           STA3_50 $ 3915           STA3_51 $ 3916        
   STA3_52 $ 3917           STA3_53 $ 3918           STA3_54 $ 3919        
   STA3_55 $ 3920           STA3_56 $ 3921           STA3_57 $ 3922        
   STA3_58 $ 3923           STA3_59 $ 3924           STA3_60 $ 3925        
   STA3_61 $ 3926           STA3_62 $ 3927           STA3_63 $ 3928        
   STA3_64 $ 3929           STA3_65 $ 3930           STA3_66 $ 3931        
   STA3_67 $ 3932           STA3_68 $ 3933           STA3_69 $ 3934        
   STA3_70 $ 3935           STA3_71 $ 3936           STA3_72 $ 3937        
   STA3_73 $ 3938           STA3_74 $ 3939           STA3_75 $ 3940        
   STA3_76 $ 3941           STA3_77 $ 3942           STA3_78 $ 3943        
   STA3_79 $ 3944           STA3_80 $ 3945           STA3_81 $ 3946        
   STA3_82 $ 3947           STA3_83 $ 3948           STA3_84 $ 3949        
   STA3_85 $ 3950           STA3_86 $ 3951           STA3_87 $ 3952        
   STA3_88 $ 3953           STA3_89 $ 3954           STA3_90 $ 3955        
   STA3_91 $ 3956           STA3_92 $ 3957           STA3_93 $ 3958        
   STA3_94 $ 3959           STA3_95 $ 3960           STA3_96 $ 3961        
   STA3_97 $ 3962           STA3_98 $ 3963           STA3_99 $ 3964        
   STA3_100 $ 3965          STA3_101 $ 3966          STA3_102 $ 3967       
   STA3_103 $ 3968          STA3_104 $ 3969          STA3_105 $ 3970       
   STA3_106 $ 3971          STA3_107 $ 3972          STA3_108 $ 3973       
   STA3_109 $ 3974          STA3_110 $ 3975          STA3_111 $ 3976       
   STA3_112 $ 3977          STA3_113 $ 3978          STA3_114 $ 3979       
   STA3_115 $ 3980          STA3_116 $ 3981          STA3_117 $ 3982       
   STA3_118 $ 3983          STA3_119 $ 3984          STA3_120 $ 3985       
   STA3_121 $ 3986          STA3_122 $ 3987          STA3_123 $ 3988       
   STA3_124 $ 3989          STA3_125 $ 3990          STA3_126 $ 3991       
   STA3_127 $ 3992          STA3_128 $ 3993          STA3_129 $ 3994       
   STA3_130 $ 3995          STA3_131 $ 3996          STA3_132 $ 3997       
   STA3_133 $ 3998          STA3_134 $ 3999          STA3_135 $ 4000       
   STA3_136 $ 4001          STA3_137 $ 4002          STA3_138 $ 4003       
   STA3_139 $ 4004          STA3_140 $ 4005          STA3_141 $ 4006       
   STA3_142 $ 4007          STA3_143 $ 4008          STA3_144 $ 4009       
   STA3_145 $ 4010          STA3_146 $ 4011          STA3_147 $ 4012       
   STA3_148 $ 4013          STA3_149 $ 4014          STA3_150 $ 4015       
   NWSTAT1 $ 4016-4026      NWSTAT2 $ 4027-4036      NWSTAT3 $ 4037-4046   
   NWSTAT4 $ 4047-4057      NWSTAT5 $ 4058-4066      NWSTAT6 $ 4067-4075   
   SMAX1  4076-4085         SMAX2  4086-4094         SMAX3  4095-4103      
   SMAX4  4104-4112         SMAX5  4113-4121         SMAX6  4122-4130      
   SMAX7  4131-4139         SMAX8  4140-4148         SMAX9  4149-4157      
   SMAX10  4158-4166        SMAX11  4167-4175        SMAX12  4176-4184     
   SMAX13  4185-4193        SMAX14  4194-4202        SMAX15  4203-4208     
   SMAX16  4209-4214        SMAX17  4215-4220        SMAX18  4221-4226     
   SMAX19  4227-4232        SMAX20  4233-4238        SMAX21  4239-4244     
   SMAX22  4245-4250        SMAX23  4251-4256        SMAX24  4257-4262     
   SMAX25  4263-4268        SMAX26  4269-4274        SMAX27  4275-4280     
   SMAX28  4281-4286        SMAX29  4287-4292        SMAX30  4293-4298     
   SMAX31  4299-4303        SMAX32  4304-4308        SMAX33  4309-4313     
   SMAX34  4314-4318        SMAX35  4319-4323        SMAX36  4324-4328     
   SMAX37  4329-4333        SMAX38  4334-4338        SMAX39  4339-4343     
   SMAX40  4344-4348        SMAX41  4349-4353        SMAX42  4354-4358     
   SMAX43  4359-4363        SMAX44  4364-4368        SMAX45  4369-4373     
   SMAX46  4374-4378        SMAX47  4379-4383        SMAX48  4384-4388     
   SMAX49  4389-4393        SMAX50  4394-4398        SMAX51  4399-4403     
   SMAX52  4404-4408        SMAX53  4409-4413        SMAX54  4414-4418     
   SMAX55  4419-4423        SMAX56  4424-4428        SMAX57  4429-4433     
   SMAX58  4434-4438        SMAX59  4439-4443        SMAX60  4444-4448     
   SMAX61  4449-4453        SMAX62  4454-4458        SMAX63  4459-4463     
   SMAX64  4464-4468        SMAX65  4469-4473        SMAX66  4474-4478     
   SMAX67  4479-4483        SMAX68  4484-4488        SMAX69  4489-4493     
   SMAX70  4494-4498        SMAX71  4499-4503        SMAX72  4504-4508     
   SMAX73  4509-4513        SMAX74  4514-4518        SMAX75  4519-4523     
   SMAX76  4524-4528        SMAX77  4529-4533        SMAX78  4534-4538     
   SMAX79  4539-4543        SMAX80  4544-4548        SMAX81  4549-4553     
   SMAX82  4554-4558        SMAX83  4559-4563        SMAX84  4564-4568     
   SMAX85  4569-4573        SMAX86  4574-4578        SMAX87  4579-4583     
   SMAX88  4584-4588        SMAX89  4589-4593        SMAX90  4594-4598     
   SMAX91  4599-4603        SMAX92  4604-4608        SMAX93  4609-4613     
   SMAX94  4614-4618        SMAX95  4619-4623        SMAX96  4624-4628     
   SMAX97  4629-4633        SMAX98  4634-4638        SMAX99  4639-4643     
   SMAX100  4644-4648       SMAX101  4649-4653       SMAX102  4654-4658    
   SMAX103  4659-4663       SMAX104  4664-4668       SMAX105  4669-4673    
   SMAX106  4674-4678       SMAX107  4679-4683       SMAX108  4684-4688    
   SMAX109  4689-4693       SMAX110  4694-4698       SMAX111  4699-4703    
   SMAX112  4704-4708       SMAX113  4709-4713       SMAX114  4714-4718    
   SMAX115  4719-4723       SMAX116  4724-4728       SMAX117  4729-4733    
   SMAX118  4734-4738       SMAX119  4739-4743       SMAX120  4744-4748    
   SMAX121  4749-4753       SMAX122  4754-4758       SMAX123  4759-4763    
   SMAX124  4764-4768       SMAX125  4769-4773       SMAX126  4774-4778    
   SMAX127  4779-4783       SMAX128  4784-4788       SMAX129  4789-4793    
   SMAX130  4794-4798       SMAX131  4799-4803       SMAX132  4804-4808    
   SMAX133  4809-4813       SMAX134  4814-4818       SMAX135  4819-4823    
   SMAX136  4824-4828       SMAX137  4829-4833       SMAX138  4834-4838    
   SMAX139  4839-4843       SMAX140  4844-4848       SMAX141  4849-4853    
   SMAX142  4854-4858       SMAX143  4859-4863       SMAX144  4864-4868    
   SMAX145  4869-4873       SMAX146  4874-4878       SMAX147  4879-4883    
   SMAX148  4884-4888       SMAX149  4889-4893       SMAX150  4894-4898    
   SMIN1  4899              SMIN2  4900              SMIN3  4901           
   SMIN4  4902-4907         SMIN5  4908              SMIN6  4909           
   SMIN7  4910              SMIN8  4911              SMIN9  4912           
   SMIN10  4913             SMIN11  4914             SMIN12  4915          
   SMIN13  4916             SMIN14  4917             SMIN15  4918          
   SMIN16  4919             SMIN17  4920             SMIN18  4921          
   SMIN19  4922             SMIN20  4923             SMIN21  4924          
   SMIN22  4925             SMIN23  4926             SMIN24  4927          
   SMIN25  4928             SMIN26  4929             SMIN27  4930          
   SMIN28  4931             SMIN29  4932             SMIN30  4933          
   SMIN31  4934             SMIN32  4935             SMIN33  4936          
   SMIN34  4937             SMIN35  4938             SMIN36  4939          
   SMIN37  4940             SMIN38  4941             SMIN39  4942          
   SMIN40  4943             SMIN41  4944             SMIN42  4945          
   SMIN43  4946             SMIN44  4947             SMIN45  4948          
   SMIN46  4949             SMIN47  4950             SMIN48  4951          
   SMIN49  4952             SMIN50  4953             SMIN51  4954          
   SMIN52  4955             SMIN53  4956             SMIN54  4957          
   SMIN55  4958             SMIN56  4959             SMIN57  4960          
   SMIN58  4961             SMIN59  4962             SMIN60  4963          
   SMIN61  4964             SMIN62  4965             SMIN63  4966          
   SMIN64  4967             SMIN65  4968             SMIN66  4969          
   SMIN67  4970             SMIN68  4971             SMIN69  4972          
   SMIN70  4973             SMIN71  4974             SMIN72  4975          
   SMIN73  4976             SMIN74  4977             SMIN75  4978          
   SMIN76  4979             SMIN77  4980             SMIN78  4981          
   SMIN79  4982             SMIN80  4983             SMIN81  4984          
   SMIN82  4985             SMIN83  4986             SMIN84  4987          
   SMIN85  4988             SMIN86  4989             SMIN87  4990          
   SMIN88  4991             SMIN89  4992             SMIN90  4993          
   SMIN91  4994             SMIN92  4995             SMIN93  4996          
   SMIN94  4997             SMIN95  4998             SMIN96  4999          
   SMIN97  5000             SMIN98  5001             SMIN99  5002          
   SMIN100  5003            SMIN101  5004            SMIN102  5005         
   SMIN103  5006            SMIN104  5007            SMIN105  5008         
   SMIN106  5009            SMIN107  5010            SMIN108  5011         
   SMIN109  5012            SMIN110  5013            SMIN111  5014         
   SMIN112  5015            SMIN113  5016            SMIN114  5017         
   SMIN115  5018            SMIN116  5019            SMIN117  5020         
   SMIN118  5021            SMIN119  5022            SMIN120  5023         
   SMIN121  5024            SMIN122  5025            SMIN123  5026         
   SMIN124  5027            SMIN125  5028            SMIN126  5029         
   SMIN127  5030            SMIN128  5031            SMIN129  5032         
   SMIN130  5033            SMIN131  5034            SMIN132  5035         
   SMIN133  5036            SMIN134  5037            SMIN135  5038         
   SMIN136  5039            SMIN137  5040            SMIN138  5041         
   SMIN139  5042            SMIN140  5043            SMIN141  5044         
   SMIN142  5045            SMIN143  5046            SMIN144  5047         
   SMIN145  5048            SMIN146  5049            SMIN147  5050         
   SMIN148  5051            SMIN149  5052            SMIN150  5053         
   RETEXT1 $ 5054-5121      RETEXT2 $ 5122           RETEXT3 $ 5123        
   RETEXT4 $ 5124           RETEXT5 $ 5125           RETEXT6 $ 5126        
   RETEXT7 $ 5127           RETEXT8 $ 5128           RETEXT9 $ 5129        
   RETEXT10 $ 5130          RESTCAT  5131            FINECAT  5132         
   SUSFNCAT  5133           LCAT1  5134              LCAT2  5135           
   LCATHI  5136             LCATS1  5137             LCATS2  5138          
   LCATSHI  5139            LCATR1  5140             LCATR2  5141          
   LCATRHI  5142            LCATC1  5143             LCATC2  5144          
   LCATCHI  5145            LCATU1  5146             LCATU2  5147          
   LCATUHI  5148          ;                       

LENGTH
   DISGORGE 6               NEWCNVTN 3               ACCEPT 3              
   BOOKER2 3                BOOKER3 3                BOOKERCD 3            
   BUSCLAS 4                CANTPAY 3                CCULPSCO 3            
   CH2APP 3                 CH8FINGD 3               CMSRVORD 3            
   COFI 3                   COMPLY 3                 COMPLYPR 3            
   CRIMPURP 3               DETBFINE 3               DISPOSIT 3            
   EMPLOYNM 3               FCULPSCO 3               FRAUDTYP 3            
   FINSTDS 3                HISTORY 3                HSMISCND 3            
   INCORLOC 3               INCORPYR 4               INDICT 3              
   INPLEA1 3                INPLEA2 3                INPLEA3 3             
   INPLEA4 3                INPLEA5 3                INPLEA6 3             
   INPLEA7 3                INPLEA8 3                INPLEA9 3             
   INPLEA10 3               INPLEA11 3               INPLEA12 3            
   INNOPL1 3                INNOPL2 3                INNOPL3 3             
   INNOPL4 3                INNOPL5 3                INNOPL6 3             
   INNOPL7 3                INNOPL8 3                INNOPL9 3             
   INNOPL10 3               INNOPL11 3               INNOPL12 3            
   JANDC 3                  NOCOMP 3                 NOCOUNTS 4            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                ORGTYPE 3                OWNSTRCT 3            
   PLEA 3                   PRIMOFF 3                PRCIVIL 3             
   PRCRIME 3                PROBATN 3                PROBMON 3             
   PSR 3                    QUARTER 3                REAS1 4               
   REAS2 4                  REAS3 3                  REAS4 3               
   REAS5 3                  REAS6 3                  REAS7 3               
   REAS8 3                  REAS9 3                  REAS10 3              
   REASONS 3                REMEDORD 3               SELFREP 3             
   SOURCES 3                TOLERNCE 3               TYPEOTHS 3            
   VICTNOTE 3               VIOLATE 3                AMENDYR 4             
   SENTYR 4                 BASEFINE 6               COSTASSM 6            
   FINOFFST 6               FORFEITR 6               GLFINMAX 6            
   GLFINMIN 6               STATMIN 6                STATMAX 6             
   CPIDN 6                  ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                ADJ_Q1 3                 ADJ_Q2 3              
   ADJ_QHI 3                ADJ_R1 3                 ADJ_R2 3              
   ADJ_RHI 3                ADJ_S1 3                 ADJ_S2 3              
   ADJ_SHI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 BASLN1 3                 BASLN2 3              
   BASLNHI 3                ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               ADJR_Q1 3                ADJR_Q2 3             
   ADJR_QHI 3               ADJR_R1 3                ADJR_R2 3             
   ADJR_RHI 3               ADJR_S1 3                ADJR_S2 3             
   ADJR_SHI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                BASLNR1 3                BASLNR2 3             
   BASLNRHI 3               ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               ADJS_Q1 3                ADJS_Q2 3             
   ADJS_QHI 3               ADJS_R1 3                ADJS_R2 3             
   ADJS_RHI 3               ADJS_S1 3                ADJS_S2 3             
   ADJS_SHI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                BASLNS1 3                BASLNS2 3             
   BASLNSHI 3               ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               ADJC_Q1 3                ADJC_Q2 3             
   ADJC_QHI 3               ADJC_R1 3                ADJC_R2 3             
   ADJC_RHI 3               ADJC_S1 3                ADJC_S2 3             
   ADJC_SHI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                BASLNC1 3                BASLNC2 3             
   BASLNCHI 3               ADJOFU1 3                ADJOFU2 3             
   ADJOFUHI 3               ADJU_B1 3                ADJU_B2 3             
   ADJU_BHI 3               ADJU_C1 3                ADJU_C2 3             
   ADJU_CHI 3               ADJU_D1 3                ADJU_D2 3             
   ADJU_DHI 3               ADJU_E1 3                ADJU_E2 3             
   ADJU_EHI 3               ADJU_F1 3                ADJU_F2 3             
   ADJU_FHI 3               ADJU_G1 3                ADJU_G2 3             
   ADJU_GHI 3               ADJU_H1 3                ADJU_H2 3             
   ADJU_HHI 3               ADJU_I1 3                ADJU_I2 3             
   ADJU_IHI 3               ADJU_J1 3                ADJU_J2 3             
   ADJU_JHI 3               ADJU_K1 3                ADJU_K2 3             
   ADJU_KHI 3               ADJU_L1 3                ADJU_L2 3             
   ADJU_LHI 3               ADJU_M1 3                ADJU_M2 3             
   ADJU_MHI 3               ADJU_N1 3                ADJU_N2 3             
   ADJU_NHI 3               ADJU_O1 3                ADJU_O2 3             
   ADJU_OHI 3               ADJU_P1 3                ADJU_P2 3             
   ADJU_PHI 3               ADJU_Q1 3                ADJU_Q2 3             
   ADJU_QHI 3               ADJU_R1 3                ADJU_R2 3             
   ADJU_RHI 3               ADJU_S1 3                ADJU_S2 3             
   ADJU_SHI 3               BASADU1 3                BASADU2 3             
   BASADUHI 3               BASEU1 3                 BASEU2 3              
   BASEUHI 3                BASLNU1 3                BASLNU2 3             
   BASLNUHI 3               SMAX1 6                  SMAX2 6               
   SMAX3 6                  SMAX4 6                  SMAX5 6               
   SMAX6 6                  SMAX7 6                  SMAX8 6               
   SMAX9 6                  SMAX10 6                 SMAX11 6              
   SMAX12 6                 SMAX13 6                 SMAX14 6              
   SMAX15 6                 SMAX16 6                 SMAX17 6              
   SMAX18 6                 SMAX19 6                 SMAX20 6              
   SMAX21 6                 SMAX22 6                 SMAX23 6              
   SMAX24 6                 SMAX25 6                 SMAX26 6              
   SMAX27 6                 SMAX28 6                 SMAX29 6              
   SMAX30 6                 SMAX31 4                 SMAX32 4              
   SMAX33 4                 SMAX34 4                 SMAX35 4              
   SMAX36 4                 SMAX37 4                 SMAX38 4              
   SMAX39 4                 SMAX40 4                 SMAX41 4              
   SMAX42 4                 SMAX43 4                 SMAX44 4              
   SMAX45 4                 SMAX46 4                 SMAX47 4              
   SMAX48 4                 SMAX49 4                 SMAX50 4              
   SMAX51 4                 SMAX52 4                 SMAX53 4              
   SMAX54 4                 SMAX55 4                 SMAX56 4              
   SMAX57 4                 SMAX58 4                 SMAX59 4              
   SMAX60 4                 SMAX61 4                 SMAX62 4              
   SMAX63 4                 SMAX64 4                 SMAX65 4              
   SMAX66 4                 SMAX67 4                 SMAX68 4              
   SMAX69 4                 SMAX70 4                 SMAX71 4              
   SMAX72 4                 SMAX73 4                 SMAX74 4              
   SMAX75 4                 SMAX76 4                 SMAX77 4              
   SMAX78 4                 SMAX79 4                 SMAX80 4              
   SMAX81 4                 SMAX82 4                 SMAX83 4              
   SMAX84 4                 SMAX85 4                 SMAX86 4              
   SMAX87 4                 SMAX88 4                 SMAX89 4              
   SMAX90 4                 SMAX91 4                 SMAX92 4              
   SMAX93 4                 SMAX94 4                 SMAX95 4              
   SMAX96 4                 SMAX97 4                 SMAX98 4              
   SMAX99 4                 SMAX100 4                SMAX101 4             
   SMAX102 4                SMAX103 4                SMAX104 4             
   SMAX105 4                SMAX106 4                SMAX107 4             
   SMAX108 4                SMAX109 4                SMAX110 4             
   SMAX111 4                SMAX112 4                SMAX113 4             
   SMAX114 4                SMAX115 4                SMAX116 4             
   SMAX117 4                SMAX118 4                SMAX119 4             
   SMAX120 4                SMAX121 4                SMAX122 4             
   SMAX123 4                SMAX124 4                SMAX125 4             
   SMAX126 4                SMAX127 4                SMAX128 4             
   SMAX129 4                SMAX130 4                SMAX131 4             
   SMAX132 4                SMAX133 4                SMAX134 4             
   SMAX135 4                SMAX136 4                SMAX137 4             
   SMAX138 4                SMAX139 4                SMAX140 4             
   SMAX141 4                SMAX142 4                SMAX143 4             
   SMAX144 4                SMAX145 4                SMAX146 4             
   SMAX147 4                SMAX148 4                SMAX149 4             
   SMAX150 4                SMIN1 3                  SMIN2 3               
   SMIN3 3                  SMIN4 6                  SMIN5 3               
   SMIN6 3                  SMIN7 3                  SMIN8 3               
   SMIN9 3                  SMIN10 3                 SMIN11 3              
   SMIN12 3                 SMIN13 3                 SMIN14 3              
   SMIN15 3                 SMIN16 3                 SMIN17 3              
   SMIN18 3                 SMIN19 3                 SMIN20 3              
   SMIN21 3                 SMIN22 3                 SMIN23 3              
   SMIN24 3                 SMIN25 3                 SMIN26 3              
   SMIN27 3                 SMIN28 3                 SMIN29 3              
   SMIN30 3                 SMIN31 3                 SMIN32 3              
   SMIN33 3                 SMIN34 3                 SMIN35 3              
   SMIN36 3                 SMIN37 3                 SMIN38 3              
   SMIN39 3                 SMIN40 3                 SMIN41 3              
   SMIN42 3                 SMIN43 3                 SMIN44 3              
   SMIN45 3                 SMIN46 3                 SMIN47 3              
   SMIN48 3                 SMIN49 3                 SMIN50 3              
   SMIN51 3                 SMIN52 3                 SMIN53 3              
   SMIN54 3                 SMIN55 3                 SMIN56 3              
   SMIN57 3                 SMIN58 3                 SMIN59 3              
   SMIN60 3                 SMIN61 3                 SMIN62 3              
   SMIN63 3                 SMIN64 3                 SMIN65 3              
   SMIN66 3                 SMIN67 3                 SMIN68 3              
   SMIN69 3                 SMIN70 3                 SMIN71 3              
   SMIN72 3                 SMIN73 3                 SMIN74 3              
   SMIN75 3                 SMIN76 3                 SMIN77 3              
   SMIN78 3                 SMIN79 3                 SMIN80 3              
   SMIN81 3                 SMIN82 3                 SMIN83 3              
   SMIN84 3                 SMIN85 3                 SMIN86 3              
   SMIN87 3                 SMIN88 3                 SMIN89 3              
   SMIN90 3                 SMIN91 3                 SMIN92 3              
   SMIN93 3                 SMIN94 3                 SMIN95 3              
   SMIN96 3                 SMIN97 3                 SMIN98 3              
   SMIN99 3                 SMIN100 3                SMIN101 3             
   SMIN102 3                SMIN103 3                SMIN104 3             
   SMIN105 3                SMIN106 3                SMIN107 3             
   SMIN108 3                SMIN109 3                SMIN110 3             
   SMIN111 3                SMIN112 3                SMIN113 3             
   SMIN114 3                SMIN115 3                SMIN116 3             
   SMIN117 3                SMIN118 3                SMIN119 3             
   SMIN120 3                SMIN121 3                SMIN122 3             
   SMIN123 3                SMIN124 3                SMIN125 3             
   SMIN126 3                SMIN127 3                SMIN128 3             
   SMIN129 3                SMIN130 3                SMIN131 3             
   SMIN132 3                SMIN133 3                SMIN134 3             
   SMIN135 3                SMIN136 3                SMIN137 3             
   SMIN138 3                SMIN139 3                SMIN140 3             
   SMIN141 3                SMIN142 3                SMIN143 3             
   SMIN144 3                SMIN145 3                SMIN146 3             
   SMIN147 3                SMIN148 3                SMIN149 3             
   SMIN150 3                RESTCAT 3                FINECAT 3             
   SUSFNCAT 3               LCAT1 3                  LCAT2 3               
   LCATHI 3                 LCATS1 3                 LCATS2 3              
   LCATSHI 3                LCATR1 3                 LCATR2 3              
   LCATRHI 3                LCATC1 3                 LCATC2 3              
   LCATCHI 3                LCATU1 3                 LCATU2 3              
   LCATUHI 3 ;

         

RUN ;
